@@ -7,6 +7,7 @@ from pyplanet.utils import times
 class LiveRankingsWidget(TimesWidgetView):
 	widget_x = -160
 	widget_y = 70.5
+	z_index = 30
 	size_x = 38
 	size_y = 55.5
 	top_entries = 5
@@ -113,6 +114,12 @@ class LiveRankingsWidget(TimesWidgetView):
 				elif record['giveup']:
 					list_record['score'] = '$iDNF'
 
+			# Points added on finishing in Rounds, Team or Cup modes.
+			if 'points_added' in record:
+				list_record['points_added'] = record['points_added']
+			else:
+				list_record['points_added'] = 0
+
 			if index == self.top_entries:
 				index = custom_start_index
 			else:
@@ -122,6 +129,13 @@ class LiveRankingsWidget(TimesWidgetView):
 		return list_records
 
 	async def get_context_data(self):
+		# Determine the Y of the widget. It should be placed under the dedimania widget if it's enabled.
+		# Otherwise, take the space below the server information on the top left.
+		self.widget_y = 12.5 if self.app.dedimania_enabled else 70.5
+		self.record_amount = await self.app.setting_rankings_amount.get_value()
+		if self.record_amount < 15:
+			self.record_amount = 15
+
 		current_script = await self.app.instance.mode_manager.get_current_script()
 		if 'TimeAttack' in current_script:
 			self.format_times = True
